GeoQueryFirestore class

Class for performing geospatial queries using Firestore and GeoHashes.

Constructors

GeoQueryFirestore({required Query<Object?> query, required String geohashFieldPath})
Creates a new instance of GeoQueryFirestore.

Properties

geohashFieldPath String
The document field path containing the GeoHash array for geospatial filtering.
final
hashCode int
The hash code for this object.
no setterinherited
query → Query<Object?>
The Firestore query for retrieving collection documents. Example:
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

byMapBounds({required LatLngBounds bounds, bool strict = true, bool enablePagination = false, int limit = 20}) Future<List<DocumentSnapshot<Object?>>>
Retrieves documents within a specified geographic bounds using GeoHashes.
byRange(LatLng center, {required GeoQueryFirestoreRanges selectedRange, double? customRangeInMeters, DocumentSnapshot<Object?>? startAfterDocument, bool enablePagination = false, int limit = 20}) Future<List<DocumentSnapshot<Object?>>>
Retrieves documents within a specified geospatial range from a given center point.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetPagination() → void
resets the pagination
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited